local me = {}

local pages = {
    home = "%1?%2",
    daily = "%1/dailies/display/5?%2",
    depot = "%1/depotitems?%2",
}

me.config = {
    link = pages.home,
    browser = true,
    open = 300
}

local useBrowser = nil
local function redirect(_, link)
    local conf = me.config
    if conf.link then
        link = link:gsub("(.*)?(.*)", conf.link)
    end

    useBrowser = false
    if conf.browser == true then
        useBrowser = true
    elseif conf.browser == 'shift' then
        useBrowser = IsShiftKeyDown()
    elseif conf.browser == 'copy' then
        Chat_CopyToClipboard(link)
        printf('Link copied: %s', link)
        useBrowser = true
        return
    end
    if useBrowser then
        SetOnTimeWebBagRequest(1);
        pylib.lib.timer.Add(conf.open, function() SetOnTimeWebBagRequest(0) end, "ZShop", 1)
        GC_OpenWebRadio(link)
    else 
        MallWeb.link = link
    end
end

local function show()
    if not useBrowser then
        MoneyWebFrame:Show();
    end
end

function me.useBrowser(val)
    printf("ZShop: %s", val and "|cff00ff00enabled|r" or "|cffff0000disabled|r")
    me.config.browser = val
    me.update()
end

function me.setLink(val)
    local link = val or pages.home
    me.config.link = val
end
function me.setOpenTime(val)
    me.config.open = val or 300
end

function me.update()
    local conf = me.config
    SetOnTimeWebBagRequest(0)
    WebXX:UnregisterEvent("WEBFRAM_URL")
    WebXX:UnregisterEvent("WEBFRAM_SHOW")
    
    pylib.RegisterEventHandler("WEBFRAM_URL", "ZShop", redirect)
    pylib.RegisterEventHandler("WEBFRAM_SHOW", "ZShop", show)
end

function me.loadConfig()
    local fn, err = loadfile("interface/addons/zshop/config.lua")
    if not fn then
        print("ZShop: Could not load config!")
        return
    end
    local res, data = pcall(fn)
    if not res then
        printf("ZShop: Could not load config: %s", data)
        return
    end
    for a,b in pairs(data) do
        me.config[a] = b
    end
    print("ZShop: Config loaded!")
end

local function init()
    me.loadConfig()
    me.update()
    pylib.RegisterEventHandler("VARIABLES_LOADED", "ZShop", me.update)
end
pcall(init)

SLASH_zshop1 = "/zshop"
function SlashCmdList.zshop(frame, msg)
    if msg:match("^%s*$") then
        me.useBrowser(not me.config.browser)
    elseif msg:match("config") then
        me.loadConfig()
        me.update()
    elseif msg:match("reload") then
        dofile("interface/addons/zshop/core.lua")
    else
        print("Commands:")
        print(" - |offffaa00/zshop|r -> enable/disable browser")
        print(" - |offffaa00/zshop config|r ->  reload the config file")
        print(" - |offffaa00/zshop help|r -> show this help")
    end
end

_G["zshop"] = me
